@@ -10,16 +10,24 @@ Dancer::Plugin::Database - easy database connections for Dancer applications
 
 =cut
 
-our $VERSION = '0.08_01';
+our $VERSION = '0.09_1';
+
+my $settings = undef;
+
+sub _load_db_settings { $settings = plugin_setting; }
 
-my $dbh;
-my $last_connection_check;
-my $settings = plugin_setting;
 my %handles;
+# Hashref used as key for default handle, so we don't have a magic value that
+# the user could use for one of their connection names and cause problems
+# (Kudos to Igor Bujna for the idea)
+my $def_handle = {};
 
 register database => sub {
-    my $name = shift || 'DPA_DEFAULT';
-    my $handle = $handles{$name};
+    my $name = shift;
+
+    _load_db_settings() if (!$settings);
+    
+    my $handle = defined($name) ? $handles{$name} : $def_handle;
     my $settings = _get_settings($name);
 
     if ($handle->{dbh}) {
@@ -31,11 +39,11 @@ register database => sub {
                 $handle->{last_connection_check} = time;
                 return $handle->{dbh};
             } else {
-                Dancer::Logger->debug(
+                Dancer::Logger::debug(
                     "Database connection went away, reconnecting"
                 );
                 if ($handle->{dbh}) { $handle->{dbh}->disconnect; }
-                return $handles{$name}->{dbh}= _get_connection();
+                return $handle->{dbh}= _get_connection();
             }
         }
     } else {
@@ -71,8 +79,10 @@ sub _get_connection {
 
         # DBD::SQLite wants 'dbname', not 'database', so special-case this
         # (DBI's documentation recommends that DBD::* modules should understand
-        # 'database', but DBD::SQLite doesn't; let's make things easier for our
-        # users by handling this for them):
+        # 'database', but older versions of DBD::SQLite didn't; let's make 
+        # things easier for our users by handling this for them):
+        # (DBD::SQLite will support 'database', too, as of 1.32 when it's
+        # released)
         if ($settings->{driver} eq 'SQLite' 
             && $settings->{database} && !$settings->{dbname}) {
             $settings->{dbname} = delete $settings->{database};
@@ -136,7 +146,7 @@ sub _get_settings {
     # If no name given, just return the default settings
     # (Take a copy and remove the connections key, so we have only the main
     # connection details)
-    if (!defined $name || $name eq 'DPA_DEFAULT') { 
+    if (!defined $name) {
         $return_settings = { %$settings };
     } else {
         # If there are no named connections in the config, bail now:
@@ -148,7 +158,7 @@ sub _get_settings {
             $return_settings = { %$settings };
         } else {
             # OK, didn't match anything
-            Dancer::Logger->error(
+            Dancer::Logger::error(
                 "Asked for a database handle named '$name' but no matching  "
                ."connection details found in config"
             );
@@ -174,9 +184,8 @@ sub _get_settings {
     get '/widget/view/:id' => sub {
         my $sth = database->prepare(
             'select * from widgets where id = ?',
-            {}, params->{id}
         );
-        $sth->execute;
+        $sth->execute(params->{id});
         template 'display_widget', { widget => $sth->fetchrow_hashref };
     };
 
@@ -294,6 +303,7 @@ Feel free to fork the repo and submit pull requests!
 
 Igor Bujna
 
+Franck Cuny
 
 =head1 BUGS
 
